//  SuperTux
//  Copyright (C) 2006 Matthias Braun <matze@braunis.de>
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include "object/candle.hpp"
#include "scripting/candle.hpp"

namespace scripting {

Candle::Candle(::Candle* candle_)
  : candle(candle_)
{ }

Candle::~Candle()
{ }

bool Candle::get_burning()
{
  return candle->get_burning();
}

void Candle::set_burning(bool burning)
{
  candle->set_burning(burning);
}

}

/* EOF */
